==> crisis-management-resources-v0.2-sources.jar: org/petalslink/officeofinfrastructure/OfficeOfInfrastructureEventProducer_EventProducerNotifier.java <==
package org.petalslink.officeofinfrastructure;

import java.util.List;
import java.util.UUID;

import javax.xml.namespace.QName;

import org.petalslink.easiestdemo.wsoui.core.WSOUIException;
import org.petalslink.easiestdemo.wsoui.provided.ProviderConfiguration;
import org.petalslink.easiestdemo.wsoui.provided.WSOUIJaxbContextItf;
import org.petalslink.easiestdemo.wsoui.provided.notification.AbstractEventProducerNotifier;

import com.ebmwebsourcing.easybox.impl.AbstractJaxbModelObject;
import com.ebmwebsourcing.wsstar.basenotification.datatypes.api.utils.WsnbException;
import com.ebmwebsourcing.wsstar.wsnb.services.impl.util.WSNHelper;

import easybox.org.oasis_open.docs.wsn.b_2.EJaxbSubscribe;
import fr.mines_albi.nuclearcrisisevent.Consequence;
import fr.mines_albi.nuclearcrisisevent.ReportEvent;

public class OfficeOfInfrastructureEventProducer_EventProducerNotifier extends AbstractEventProducerNotifier {

	public OfficeOfInfrastructureEventProducer_EventProducerNotifier(ProviderConfiguration configuration, WSOUIJaxbContextItf context) throws WSOUIException {
		super(configuration, context);
		this.getSubscriptionManager().setTopicSet(Thread.currentThread().getContextClassLoader().getResource("crisis/v3/EventTopicSetOffice.xml"));
		this.getSubscriptionManager().setTopicNamespace(Thread.currentThread().getContextClassLoader().getResource("crisis/v3/EventTopicNS.xml"));
	}

	@Override
	public void setPeriodEvent() {
		this.setPeriodEvent(0); // Set the period to send event (in ms).
	}


	@Override
	public Object createPeriodicallyEvent() throws WSOUIException {
		Object event = null; // TODO: create Event.
		return event;
	}


	@Override
	public Object createEventBeforeProcessingRequest(String methodName, Object request) throws WSOUIException {
		Object event = null; // TODO: create Event.
		return event;
	}


	@Override
	public Object createEventBeforeSendResponse(String methodName, Object request, Object response) throws WSOUIException {
		try {
			if(methodName.equals("subscribe")) {
				System.out.println("maven-wsoui  request: " + request);
				EJaxbSubscribe subscribe = (EJaxbSubscribe) request;
				List<QName> msgs = WSNHelper.getMessages(WSNHelper.getMessageContentInFilter(subscribe.getFilter()));
				System.out.println("maven-wsoui topic: " + msgs);
				System.out.println("maven-wsoui topic must be equals to: reportevent");
				if(!msgs.isEmpty() && msgs.get(0).getLocalPart().toLowerCase().equals("reportevent")) {
					ReportEvent event = new ReportEvent();
					event.setUid(UUID.randomUUID().toString());
					Consequence c = new Consequence();
					c.setActivityID("Plan de circulation");
					event.setConsequence(c);
					System.out.println("maven-wsoui methodName = " + methodName);
					System.out.println("maven-wsoui request = " + request);
					System.out.println("maven-wsoui +++++++++++++++++++++++++++++++ CREATION AND SEND OF ReportEvent EVENT");
					return event;
				}
			}
		} catch (WsnbException e) {
			throw new WSOUIException(e);
		}
		return null;
	}



}

==> crisis-management-resources-v0.5-sources.jar: org/petalslink/officeofinfrastructure/OfficeOfInfrastructureEventProducer_EventProducerNotifier.java <==
package org.petalslink.officeofinfrastructure;

import java.util.List;
import java.util.UUID;

import javax.xml.namespace.QName;

import org.petalslink.easiestdemo.wsoui.core.WSOUIException;
import org.petalslink.easiestdemo.wsoui.provided.ProviderConfiguration;
import org.petalslink.easiestdemo.wsoui.provided.WSOUIJaxbContextItf;
import org.petalslink.easiestdemo.wsoui.provided.notification.AbstractEventProducerNotifier;

import com.ebmwebsourcing.easybox.impl.AbstractJaxbModelObject;
import com.ebmwebsourcing.wsstar.basenotification.datatypes.api.utils.WsnbException;
import com.ebmwebsourcing.wsstar.wsnb.services.impl.util.WSNHelper;

import easybox.org.oasis_open.docs.wsn.b_2.EJaxbSubscribe;
import fr.mines_albi.nuclearcrisisevent.Consequence;
import fr.mines_albi.nuclearcrisisevent.ReportEvent;

public class OfficeOfInfrastructureEventProducer_EventProducerNotifier extends AbstractEventProducerNotifier {

	public OfficeOfInfrastructureEventProducer_EventProducerNotifier(ProviderConfiguration configuration, WSOUIJaxbContextItf context) throws WSOUIException {
		super(configuration, context);
		this.getSubscriptionManager().setTopicSet(Thread.currentThread().getContextClassLoader().getResource("crisis/v3/EventTopicSetOffice.xml"));
		this.getSubscriptionManager().setTopicNamespace(Thread.currentThread().getContextClassLoader().getResource("crisis/v3/EventTopicNS.topns"));
	}

	@Override
	public void setPeriodEvent() {
		this.setPeriodEvent(0); // Set the period to send event (in ms).
	}


	@Override
	public Object createPeriodicallyEvent() throws WSOUIException {
		Object event = null; // TODO: create Event.
		return event;
	}


	@Override
	public Object createEventBeforeProcessingRequest(String methodName, Object request) throws WSOUIException {
		Object event = null; // TODO: create Event.
		return event;
	}


	@Override
	public Object createEventBeforeSendResponse(String methodName, Object request, Object response) throws WSOUIException {
		try {
			if(methodName.equals("subscribe")) {
				System.out.println("maven-wsoui  request: " + request);
				EJaxbSubscribe subscribe = (EJaxbSubscribe) request;
				List<QName> msgs = WSNHelper.getMessages(WSNHelper.getMessageContentInFilter(subscribe.getFilter()));
				System.out.println("maven-wsoui topic: " + msgs);
				System.out.println("maven-wsoui topic must be equals to: reportevent");
				if(!msgs.isEmpty() && msgs.get(0).getLocalPart().toLowerCase().equals("reportevent")) {
					ReportEvent event = new ReportEvent();
					event.setUid(UUID.randomUUID().toString());
					Consequence c = new Consequence();
					c.setActivityID("Plan de circulation");
					event.setConsequence(c);
					System.out.println("maven-wsoui methodName = " + methodName);
					System.out.println("maven-wsoui request = " + request);
					System.out.println("maven-wsoui +++++++++++++++++++++++++++++++ CREATION AND SEND OF ReportEvent EVENT");
					return event;
				}
			}
		} catch (WsnbException e) {
			throw new WSOUIException(e);
		}
		return null;
	}



}
